multiprovider_analytics
library
Classes
-
Analytic
-
Defines the structure of an analytic event.
-
AnalyticsPage
-
Interface that needs to be used on every page to track analytics.
It is used to define the name of the page to be tracked.
-
AnalyticsPostBlocEvent<T>
-
Defines the necessary for handling analytics after a bloc event has been
processed by a BLoC. Use this mixin when the data you should track must be
provided dynamically (by processing something in the BLoC)
-
AnalyticsPreBlocEvent<T>
-
Defines de structure of analytics on a bloc event. Always prefer this mixin
-
MultiProviderAnalytics
-
Manager de Analiticas para diferentes servicios
-
MultiProviderAnalyticsBlocObserver
-
A
BlocObserver which observes all Bloc state changes and
tracks analytics events.