Interface that needs to be used on every page to track analytics. It is used to define the name of the page to be tracked.
Example:
class HomePage extends StatelessWidget with AnalyticsPage {
@override
String get analyticsPageName => 'Home';
}
Constructors
Properties
- analyticsPageName → String
-
The name of the page to be tracked.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited